<?php

class SitemapBehavior extends ModelBehavior {

	public $settings = array();

	public function setup(Model $Model, $settings = array()) {
		if (!isset($this->settings[$Model->alias])) {
			// assemble based on default params defined in config
			$this->settings[$Model->alias] = Configure::read('EvSitemap.defaults');
		}

		$this->settings[$Model->alias] = array_merge($this->settings[$Model->alias], $settings);
	}

	public function getSitemapData(Model $Model) {
		$modelData = $Model->find('all', array(
			'conditions' => $this->settings[$Model->alias]['conditions'],
			'recursive' => -1
		));

		return $this->_assembleSitemap($Model, $modelData);
	}

	protected function _assembleSitemap(Model $Model, $modelData = array()) {
		$data = array();

		if (! empty($modelData)) {
			foreach ($modelData as $key => $item) {

				if (
					in_array(
						$item[$Model->alias][$this->settings[$Model->alias]['primaryKey']],
						$this->settings[$Model->alias]['ignoreList']
					)
				) {

					continue;
				}

				$data[$key] = array();

				$pluginName = null;
				$controllerName = Inflector::tableize($Model->name);
				$controllerAction = $this->settings[$Model->alias]['controllerAction'];

				//If the controller has been overridden and a plugin has been provided, set it here
				if (isset($Model->actsAs['Sitemap']['plugin'])) {
					$pluginName = $Model->actsAs['Sitemap']['plugin'];
				}

				if (isset($Model->actsAs['Sitemap']['controller'])) {
					$controllerName = $Model->actsAs['Sitemap']['controller'];
				}

				if (isset($Model->actsAs['Sitemap']['controllerAction'])) {
					$controllerAction = $Model->actsAs['Sitemap']['controllerAction'];
				}

				// URL used for the sitemap is generated from its Route by default, but will populate from a custom function if available
				if (method_exists($Model, $this->settings[$Model->alias]['loc']) && is_callable(array($Model, $this->settings[$Model->alias]['loc']))) {
					$data[$key]['loc'] = call_user_func(array($Model, $this->settings[$Model->alias]['loc']), $item);
				} else {
					$data[$key]['loc'] = Router::url(array(
						'plugin' => $pluginName,
						'controller' => $controllerName,
						'action' => $controllerAction,
						$item[$Model->alias][$this->settings[$Model->alias]['primaryKey']]
					), true);
				}

				if ($this->settings[$Model->alias]['lastmod'] !== false) {
					$data[$key]['lastmod'] = $item[$Model->alias][$this->settings[$Model->alias]['lastmod']];
				}

				if ($this->settings[$Model->alias]['changefreq'] !== false) {
					$data[$key]['changefreq'] = $this->settings[$Model->alias]['changefreq'];
				}

				if ($this->settings[$Model->alias]['readPriority'] !== false) {
					$data[$key]['readPriority'] = $this->settings[$Model->alias]['readPriority'];
				}

				// include the item name / title for the website version
				if (isset($Model->displayField) && isset($item[$Model->alias][$Model->displayField])) {
					$data[$key]['name'] = $item[$Model->alias][$Model->displayField];
				}

			}
		}

		return $data;
	}

}
